<?php

if ( ! function_exists( 'bt_my_account_url' ) ) {
	/**
	 * Get URL for the my account page.
	 *
	 * @return false|string
	 */
	function bt_my_account_url() {
		return get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );
	}
}


if ( ! function_exists( 'bt_my_account_redirect' ) ) {
	/**
	 * Redirect to the my account page, optionally with a URL to then redirect to upon signing in.
	 *
	 * @return false|string
	 */
	function bt_my_account_redirect( $redirect_upon_signin = '' ) {
    $redirect =
      $redirect_upon_signin
        ? add_query_arg( 'redirect_to', $redirect_upon_signin, bt_my_account_url() )
        : bt_my_account_url()
    ;

    wp_redirect( str_replace( home_url(), '', $redirect ) );
	}
}


/**
 * Update items in My Account menu (e.g. remove downloads).
 */
add_filter ( 'woocommerce_account_menu_items', function ( $menu_links ) {
	//error_log( '--------------------' );
	//error_log( '[bt-ecomm] ACCOUNT MENU - BEFORE: ' . print_r( $menu_links, 1 ) );

	// remove downloads
	unset( $menu_links['downloads'] );

	// update title of things that need it so everything is capitalized
	$menu_links['edit-account'] = 'Account Details';
	$menu_links['payment-methods'] = 'Payment Methods';

	// tweak components based on account type
	if ( bt_is_seller() || bt_is_subscriber_could_be_seller() ) {
		// seller

		// update title of edit-account so everything is capitalized
		/* $seller_post_type = bt_use_sellers( 'seller_post_type' );
		if ( ! empty( $seller_post_type ) ) {
			$menu_links['edit-account'] = $seller_post_type . ' Details';
		} */

		// remove unused things
		unset( $menu_links['downloads'] );
		unset( $menu_links['edit-account'] );

		// remove logout for now, to append after we add custom things
		$logout = $menu_links['customer-logout'];
		unset( $menu_links['customer-logout'] );

		// add seller things
		//$menu_links['reports'] = 'Sales Reports';
		//$menu_links['connect-with-stripe'] = 'Connect With Stripe';

		// add logout back to end
		$menu_links['customer-logout'] = $logout;

	} else {
		// customer

		// update title of edit-account so everything is capitalized
		// GLOBAL NOW $menu_links['edit-account'] = 'Account Details';
	}

	//error_log( 'ACCOUNT MENU - AFTER: ' . print_r( $menu_links, 1 ) );

	return $menu_links;
});


/**
 * Customize title of edit-account endpoint so that all words are capitalized.
 */
add_filter( 'woocommerce_endpoint_edit-account_title', function ( $title ) {
	return __( 'Account Details', 'woocommerce' );
} );


/**
 * Add an "Order Again" button to the list of orders in my account, if bt-ecomm option exists.
 */
add_filter( 'woocommerce_my_account_my_orders_actions', function( $actions, $order ) {
	if ( bt_ecomm_option( 'account_show_order_again' ) ) {
		//error_log( '-- ID ' . $order->get_id() . ' with status ' . $order->get_status() . ': ' . print_r( $order->get_meta( '_completed_subscription_switch' ), 1 ) );
		if ( $order->has_status( ['completed', 'wc-completed-picked', 'wc-completed-shipped' ]) && ! $order->get_meta( '_completed_subscription_switch' ) ) {
			$actions['order-again'] = array(
				'url'  => wp_nonce_url( add_query_arg( 'order_again', $order->get_id() ) , 'woocommerce-order_again' ),
				'name' => __( 'Order Again', 'woocommerce' )
			);
		}
	}
	return $actions;
}, 50, 2 );


/**
 * Hook into view-order within my account, to add information about the seller.
 */
add_action( 'woocommerce_view_order', 'bt_cart_seller_header' );
